==> claromentis-framework-9.6.6-26891208.zip: web/intranet/people/classes/legacy/UsersFieldsConfigAdmin.php <==
<?php
$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"] ?: array()) + array();
use Claromentis\People\UserFieldsConfigService;








class UsersFieldsConfigAdmin extends UsersFieldsConfig
{
    
    
    
    
    
    
    
    public static function SetFieldsUsersList($_53c1e9242cd17b423a4fc712c758b5e9)
    {
        self::I()->SetFieldsUsersList($_53c1e9242cd17b423a4fc712c758b5e9);
    }
    
    
    
    
    
    
    
    public static function SetFieldsAdvancedSearch($_53c1e9242cd17b423a4fc712c758b5e9)
    {
        self::I()->SetFieldsAdvancedSearch($_53c1e9242cd17b423a4fc712c758b5e9);
    }
    
    
    
    
    
    
    
    public static function SetFieldsViewProfile($_53c1e9242cd17b423a4fc712c758b5e9)
    {
        self::I()->SetFieldsViewProfile($_53c1e9242cd17b423a4fc712c758b5e9);
    }
    
    
    
    
    
    
    public static function SetFieldsViewProfileTop($_53c1e9242cd17b423a4fc712c758b5e9)
    {
        self::I()->SetFieldsViewProfileTop($_53c1e9242cd17b423a4fc712c758b5e9);
    }
    
    
    
    
    
    
    
    public static function SetFieldsMyProfile($_53c1e9242cd17b423a4fc712c758b5e9)
    {
        self::I()->SetFieldsMyProfile($_53c1e9242cd17b423a4fc712c758b5e9);
    }
    
    
    
    
    
    
    
    public static function SetFieldsAdminProfile($_53c1e9242cd17b423a4fc712c758b5e9)
    {
        self::I()->SetFieldsAdminProfile($_53c1e9242cd17b423a4fc712c758b5e9);
    }
    
    
    
    
    
    
    
    public static function SetFieldsAdminList($_53c1e9242cd17b423a4fc712c758b5e9)
    {
        self::I()->SetFieldsAdminList($_53c1e9242cd17b423a4fc712c758b5e9);
    }
    
    
    
    
    
    
    
    public static function GetAllFieldsForMode($mode)
    {
        return self::I()->GetAllFieldsForMode($mode);
    }
    
    
    
    
    
    
    
    
    
    public static function GetFieldsByMode($mode)
    {
        return self::I()->GetFieldsByMode($mode);
    }
    
    
    
    
    
    
    
    
    
    public static function SetFieldsByMode($mode, $_53c1e9242cd17b423a4fc712c758b5e9)
    {
        self::I()->SetFieldsByMode($mode, $_53c1e9242cd17b423a4fc712c758b5e9);
    }
    
    
    
    
    
    
    
    public static function GetFieldDisplayedOn($_66dc8b21e839a9a4739443a621ecc45a)
    {
        return self::I()->GetFieldDisplayedOn($_66dc8b21e839a9a4739443a621ecc45a);
    }
    
    
    
    
    
    
    
    
    
    
    public static function SetEditable($mode, $_66dc8b21e839a9a4739443a621ecc45a, $_12c9aee000f1cc8bcf9846556ecc3544)
    {
        self::I()->SetEditable($mode, $_66dc8b21e839a9a4739443a621ecc45a, $_12c9aee000f1cc8bcf9846556ecc3544);
    }
    public static function GetMyProfileReadonlyFields()
    {
        return self::I()->GetMyProfileReadonlyFields();
    }
    public static function RemoveField($_66dc8b21e839a9a4739443a621ecc45a)
    {
        self::I()->RemoveField($_66dc8b21e839a9a4739443a621ecc45a);
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/people/classes/legacy/UsersFieldsConfigAdmin.php <==
<?php
$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"] = (@$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"] ?: array()) + array();
use Claromentis\People\UserFieldsConfigService;








class UsersFieldsConfigAdmin extends UsersFieldsConfig
{
    
    
    
    
    
    
    
    public static function SetFieldsUsersList($_53c1e9242cd17b423a4fc712c758b5e9)
    {
        self::I()->SetFieldsUsersList($_53c1e9242cd17b423a4fc712c758b5e9);
    }
    
    
    
    
    
    
    
    public static function SetFieldsAdvancedSearch($_53c1e9242cd17b423a4fc712c758b5e9)
    {
        self::I()->SetFieldsAdvancedSearch($_53c1e9242cd17b423a4fc712c758b5e9);
    }
    
    
    
    
    
    
    
    public static function SetFieldsViewProfile($_53c1e9242cd17b423a4fc712c758b5e9)
    {
        self::I()->SetFieldsViewProfile($_53c1e9242cd17b423a4fc712c758b5e9);
    }
    
    
    
    
    
    
    public static function SetFieldsViewProfileTop($_53c1e9242cd17b423a4fc712c758b5e9)
    {
        self::I()->SetFieldsViewProfileTop($_53c1e9242cd17b423a4fc712c758b5e9);
    }
    
    
    
    
    
    
    
    public static function SetFieldsMyProfile($_53c1e9242cd17b423a4fc712c758b5e9)
    {
        self::I()->SetFieldsMyProfile($_53c1e9242cd17b423a4fc712c758b5e9);
    }
    
    
    
    
    
    
    
    public static function SetFieldsAdminProfile($_53c1e9242cd17b423a4fc712c758b5e9)
    {
        self::I()->SetFieldsAdminProfile($_53c1e9242cd17b423a4fc712c758b5e9);
    }
    
    
    
    
    
    
    
    public static function SetFieldsAdminList($_53c1e9242cd17b423a4fc712c758b5e9)
    {
        self::I()->SetFieldsAdminList($_53c1e9242cd17b423a4fc712c758b5e9);
    }
    
    
    
    
    
    
    
    public static function GetAllFieldsForMode($mode)
    {
        return self::I()->GetAllFieldsForMode($mode);
    }
    
    
    
    
    
    
    
    
    
    public static function GetFieldsByMode($mode)
    {
        return self::I()->GetFieldsByMode($mode);
    }
    
    
    
    
    
    
    
    
    
    public static function SetFieldsByMode($mode, $_53c1e9242cd17b423a4fc712c758b5e9)
    {
        self::I()->SetFieldsByMode($mode, $_53c1e9242cd17b423a4fc712c758b5e9);
    }
    
    
    
    
    
    
    
    public static function GetFieldDisplayedOn($_66dc8b21e839a9a4739443a621ecc45a)
    {
        return self::I()->GetFieldDisplayedOn($_66dc8b21e839a9a4739443a621ecc45a);
    }
    
    
    
    
    
    
    
    
    
    
    public static function SetEditable($mode, $_66dc8b21e839a9a4739443a621ecc45a, $_12c9aee000f1cc8bcf9846556ecc3544)
    {
        self::I()->SetEditable($mode, $_66dc8b21e839a9a4739443a621ecc45a, $_12c9aee000f1cc8bcf9846556ecc3544);
    }
    public static function GetMyProfileReadonlyFields()
    {
        return self::I()->GetMyProfileReadonlyFields();
    }
    public static function RemoveField($_66dc8b21e839a9a4739443a621ecc45a)
    {
        self::I()->RemoveField($_66dc8b21e839a9a4739443a621ecc45a);
    }
}
